@@ -32,11 +32,11 @@
 #'   makeLogicalParam("x"),
 #'   makeDiscreteVectorParam("y", len=2, values=c("a", "b"))
 #' )
-makeParamSet = function(..., params, forbidden = NULL) {
+makeParamSet = function(..., params = NULL, forbidden = NULL) {
   pars = list(...)
-  if (length(pars) > 0 && !missing(params))
+  if (length(pars) > 0 && !is.null(params))
     stop("You can only use one of ... or params!")
-  if (!missing(params)) {
+  if (!is.null(params)) {
     assertList(params, types = "Param")
     pars = params
   } else {
@@ -46,12 +46,12 @@ makeParamSet = function(..., params, forbidden = NULL) {
   if (any(duplicated(ns)))
     stop("All parameters must have unique names!")
   names(pars) = ns
-  makeS3Obj("ParamSet", pars = pars, forbidden = forbidden)
+  return(makeS3Obj("ParamSet", pars = pars, forbidden = forbidden))
 }
 
 getParSetPrintData = function(x, trafo = TRUE, used = TRUE, constr.clip = 40L) {
   d = lapply(x$pars, getParPrintData, trafo = trafo, used = used, constr.clip = constr.clip)
-  do.call(rbind, d)
+  return(do.call(rbind, d))
 }
 
 #' @export
@@ -63,14 +63,17 @@ print.ParamSet = function(x, ..., trafo = TRUE, used = TRUE, constr.clip = 40L)
   }
   if (hasForbidden(x))
     catf("Forbidden region specified.")
-  invisible(NULL)
+  return(invisible(NULL))
 }
 
 #' @export
-c.ParamSet = function(..., recursive=FALSE) {
+c.ParamSet = function(..., recursive = FALSE) {
   pss = list(...)
   pars = Reduce(c, lapply(pss, function(ps) ps$pars))
-  do.call(makeParamSet, pars)
+  # remove the names here. if 'params' is a par name, this wont work in the contructor call
+  # but we are allowed to pass the list without names, as they are set again automatically later for pars
+  names(pars) = NULL
+  return(do.call(makeParamSet, pars))
 }
 
 #' Check whether parameter set is empty.
@@ -86,7 +89,7 @@ isEmpty = function(par.set) {
 
 #' @export
 isEmpty.ParamSet = function(par.set) {
-  length(par.set$pars) == 0
+  return(length(par.set$pars) == 0)
 }
 
 #' \code{makeNumericParamSet}: Convenience function for numerics.
@@ -107,7 +110,7 @@ isEmpty.ParamSet = function(par.set) {
 #'   Default is \code{TRUE}.
 #' @rdname makeParamSet
 #' @export
-makeNumericParamSet = function(id="x", len, lower=-Inf, upper=Inf, vector=TRUE) {
+makeNumericParamSet = function(id = "x", len, lower = -Inf, upper = Inf, vector = TRUE) {
   assertString(id)
   if (missing(len)) {
     if (!missing(lower))
@@ -125,10 +128,11 @@ makeNumericParamSet = function(id="x", len, lower=-Inf, upper=Inf, vector=TRUE)
     assertNumeric(upper, len = len)
     assertFlag(vector)
   if (vector) {
-    makeParamSet(makeNumericVectorParam(id=id, len=len, lower=lower, upper=upper))
+    return(makeParamSet(makeNumericVectorParam(id = id, len = len, lower = lower, upper = upper)))
   } else {
-    makeParamSet(params=lapply(1:len, function(i)
-      makeNumericParam(id=paste(id, i, sep=""), lower=lower[i], upper=upper[i])))
+    return(makeParamSet(params = lapply(1:len, function(i)
+      makeNumericParam(id = paste(id, i, sep = ""), lower = lower[i], upper = upper[i]))
+    ))
   }
 }
 
