@@ -11,10 +11,11 @@
 #' If you want to convert these, look at \code{\link[BBmisc]{convertDataFrameCols}}.
 #' Dependent parameters whose constraints are unsatisfied generate \code{NA} entries in their
 #' respective columns.
+#' For discrete vectors the levels and their order will be preserved.
 #'
 #' The algorithm currently performs these steps:
 #' \enumerate{
-#'   \item{We create a grid. For numerics and integers we use the specfied resolution.}
+#'   \item{We create a grid. For numerics and integers we use the specfied resolution. For discretes all values will be taken.}
 #'   \item{Forbidden points are removed.}
 #'   \item{Parameters are trafoed (maybe); dependent parameters whose constraints are unsatisfied
 #'     are set to \code{NA} entries.}
@@ -134,6 +135,10 @@ generateGridDesign = function(par.set, resolution, trafo = FALSE) {
   res = res[!duplicated(res), , drop = FALSE]
 
   res = convertDataFrameCols(res, chars.as.factor = TRUE)
+
+  #fix factors
+  res = fixDesignFactors(res, par.set)
+
   attr(res, "trafo") = trafo
   return(res)
 }
