@@ -7,9 +7,10 @@ test_that("getDefaults", {
   ps = makeParamSet(
     makeNumericParam("u", default = 2),
     makeIntegerParam("v"),
+    makeCharacterParam("s", default = "foo"),
     makeUntypedParam("w", default = iris)
   )
-  expect_equal(getDefaults(ps), list(u = 2, w = iris))
+  expect_equal(getDefaults(ps), list(u = 2, s = "foo", w = iris))
 
   ps = makeParamSet(
     makeIntegerParam("v")
@@ -19,7 +20,7 @@ test_that("getDefaults", {
   # test include.null
   ps = makeParamSet(
     makeDiscreteParam("x", values = c("a", "b"), default = "a"),
-    makeNumericVectorParam("y", len=2),
+    makeNumericVectorParam("y", len = 2),
     makeIntegerParam("z", default = 99)
   )
   expect_equal(
